@@ -485,18 +485,26 @@ class Container(object):
         self._write_fig_cfg(True)
         if rebuild and 'build' in self._testing['test']:
             try:
-                args = self._get_fig_args('buid', 'test')
+                args = self._get_fig_args('build', 'test')
                 subprocess.check_call(args, cwd=self.path)
             except subprocess.CalledProcessError:
                 msg = "{} test failed: failed to rebuild test container"
                 raise ContainerError(msg.format(self.tag))
 
+        try:
+            services = set(self._get_fig_cfg(True).keys()) - {'test'}
+            args = self._get_fig_args('up', '-d', *services)
+            subprocess.check_call(args, cwd=self.path)
+        except subprocess.CalledProcessError:
+            raise ContainerError("{} test failed: failed to start dependencies")
+
         try:
             args = self._get_fig_args('run', '--rm', 'test')
             exit_code = subprocess.call(args, cwd=self.path)
             if exit_code != 0:
                 msg = "{} test failed: returned non-zero exit code {}"
                 raise TestError(msg.format(self.tag, exit_code), exit_code)
+
         except KeyboardInterrupt:
             raise ContainerError("{} test failed: interrupted".format(self.tag))
         finally:
